_`umbra.components.addons.tcpClientUi.tcpClientUi`
==================================================

.. automodule:: umbra.components.addons.tcpClientUi.tcpClientUi

Module Attributes
-----------------

.. attribute:: umbra.components.addons.tcpClientUi.tcpClientUi.LOGGER

.. attribute:: umbra.components.addons.tcpClientUi.tcpClientUi.COMPONENT_UI_FILE

Classes
-------

.. autoclass:: TCPClientUi
	:show-inheritance:
	:members:

